@@ -4,19 +4,19 @@
 * Botan is released under the Simplified BSD License (see license.txt)
 */
 
-#ifndef BOTAN_EME_RAW_H__
-#define BOTAN_EME_RAW_H__
+#ifndef BOTAN_EME_RAW_H_
+#define BOTAN_EME_RAW_H_
 
 #include <botan/eme.h>
 
 namespace Botan {
 
-class BOTAN_DLL EME_Raw final : public EME
+class BOTAN_PUBLIC_API(2,0) EME_Raw final : public EME
    {
    public:
       size_t maximum_input_size(size_t i) const override;
 
-      EME_Raw() {}
+      EME_Raw() = default;
    private:
       secure_vector<uint8_t> pad(const uint8_t[], size_t, size_t,
                              RandomNumberGenerator&) const override;
